import { Component, EventEmitter, Input, Output } from '@angular/core';
import { ButtonTypeV3 } from './button.type';

@Component({
  selector: 'app-v3-button',
  templateUrl: './button.component.html',
  styleUrls: ['./button.component.scss'],
})
export class ButtonV3Component {
  /** HTML type of the button */
  @Input() type: 'submit' | 'button' | 'reset' = 'button';

  /** Button label */
  @Input() label: string = 'Bouton';

  /** What variant should be the button ? */
  @Input() variant?: ButtonTypeV3 = ButtonTypeV3.Primary;

  /** Affects the height of the button */
  @Input() size?: 'small' | 'medium' | 'large' = 'small';

  /** Should the button be wide ? (250px) */
  @Input() wide?: boolean = false;

  /** Should the button be disabled ? */
  @Input() disabled?: boolean = false;

  /** Sets the position of the icon if one provided */
  @Input() iconPosition: 'left' | 'right' = 'left';

  /** Folder of the icon ex: assets/ico */
  @Input() iconFolder: string = 'ico';

  /** Icon name */
  @Input() iconName: string;

  /** Click handler */
  @Output() action = new EventEmitter<Event>();

  public get classes(): string[] {
    return [this.variant, this.size, this.wide ? 'wide' : ''];
  }
}
