import { CommonModule } from '@angular/common';
import { EventEmitter } from '@angular/core';
import type { Meta, StoryObj } from '@storybook/angular';
import { moduleMetadata } from '@storybook/angular';
import { SvgIconComponent } from '../../../svg-icon/svg-icon.component';
import { TagItemV3Component } from './tag-item.component';

// More on how to set up stories at: https://storybook.js.org/docs/angular/writing-stories/introduction
const meta: Meta<TagItemV3Component> = {
  title: 'Components/Tag item',
  component: TagItemV3Component,
  tags: ['autodocs'],
  decorators: [
    moduleMetadata({
      declarations: [SvgIconComponent],
      imports: [CommonModule],
    }),
  ],
  argTypes: {},
};

export default meta;
type Story = StoryObj<TagItemV3Component>;

export const SmallTag: Story = {
  args: {
    label: 'Label tag',
    size: 'small',
    clickable: true,
    disabled: false,
    selected: false,
    action: new EventEmitter(),
  },
};

export const SmallTagWithIcon: Story = {
  args: {
    ...SmallTag.args,
    iconFolder: 'ico',
    iconName: 'email',
  },
};

export const SmallTagSelected: Story = {
  args: {
    ...SmallTag.args,
    selected: true,
  },
};

export const MediumTag: Story = {
  args: {
    label: 'Medium tag',
    size: 'medium',
  },
};

export const MediumTagWithIcon: Story = {
  args: {
    ...MediumTag.args,
    iconFolder: 'ico',
    iconName: 'email',
  },
};

export const Unclickable: Story = {
  args: {
    label: 'Unclickable tag',
    clickable: false,
  },
};

export const UnclickableWithIcon: Story = {
  args: {
    ...Unclickable.args,
    iconFolder: 'ico',
    iconName: 'email',
  },
};

export const MultipleTags: Story = {
  render: (args) => ({
    props: args,
    template: `
    <div class="btn-grid">
      <app-v3-tag-item label="test 1" />
      <app-v3-tag-item label="test 2" selected="true" />
      <app-v3-tag-item label="test 3" />
    </div>`,
  }),
};
